#  Copyright (C) 2023
#  ABM, Moscow
#
#  UNPUBLISHED PROPRIETARY MATERIAL.
#  ALL RIGHTS RESERVED.
#
#  Authors: Revva Konstantin <k.revva@abm-jsc.ru>


from detector_connector import DetectorConnector, DetectorAnalyzeResult

from shift_detector_connector.shift_settings import ShiftSettings


class ShiftDetectorConnector(DetectorConnector):
    Context = DetectorConnector.Context
    Config = DetectorConnector.Config

    def __init__(self, config: Config, context: Context):
        super().__init__(config=config,
                         context=context,
                         detector_analyze_result_type=DetectorAnalyzeResult,
                         detector_settings_type=ShiftSettings)
